Lua_TrialPanel = class("Lua_TrialPanel", Lua_DisplayObject);
function Lua_TrialPanel:ctor(p)
	self:superCall("ctor", p, "TrialPanel_skin");
end

function Lua_TrialPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardBg:setLocation(0, 621 + self.adaptHeight / 2);
	self.rewardBg:SetDimensions(720, 758 + self.adaptHeight);

	self.taskList = Lua_DragList.new(self.content, 710, 730 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.taskList:setListCell(Lua_TrialEachItem, 710, 164, 1);
	self.taskList:setLocation(0, 265 + self.adaptHeight / 2, 0);
	self.taskList:setRectPivot(1);

	self.tips:addClickFuntion(self, self.onTipsBtnClick);

	self:addLuaEvent("UPDATE_TRIAL_TYPE_INFO", self, self.updateData);
end

function Lua_TrialPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.rewardBg:setLocation(0, 621 + adaptHeight / 2);
	self.rewardBg:SetDimensions(720, 758 + adaptHeight);

	self.taskList:setLocation(0, 265 + adaptHeight / 2, 0);
	self.taskList:setContentRect(710, 730 + adaptHeight);
end

function Lua_TrialPanel:setType(curSelectType)
	self.selectType = curSelectType;
	self.isFirst = true;

	DataCenter.TrialData.trial_select_type = curSelectType;
	self.winBg:setUrl("/images/trial/ui_shilian_bj_00"..curSelectType..".jpg");
end

function Lua_TrialPanel:updateData(curSelectType)
	if self.selectType ~= curSelectType then
		return;
	end

	DataCenter.TrialData:getTypeRecIndex(self.selectType);

	local data = DataCenter.TrialData:getTrialTypeById(self.selectType);
	self.taskList:setArrayData(data.script_arr);

	if self.isFirst then
		self.isFirst = false;
		self.taskList:moveToIndex(DataCenter.TrialData.selectIdx, true, false);
	end

	if data.free_times > 0 then
		self.freeTimesTxt.text = LanUtil.formateStr(200601, data.free_times);
	else
		self.freeTimesTxt.text = LanUtil.formateStr(200602, data.challenge_times);
	end
end

function Lua_TrialPanel:onTipsBtnClick(go)
	local tipData = { des = LanUtil.getValue(200611), posX = 210, posY = -425 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_TrialPanel:dispose()
	if self.taskList ~= nil then
		self.taskList:dispose();
		self.taskList = nil;
	end

	self:superCall("dispose")
end





--------------------------------------------------





Lua_TrialEachItem = class("Lua_TrialEachItem", Lua_ListCell);
function Lua_TrialEachItem:ctor(p)
    self:superCall("ctor", p, "TrialItem_skin");
end

function Lua_TrialEachItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_ItemIconList.new(self.content);
	self.rewardList:setLocation(-30, 0, 0);
	self.rewardList:setSiblingIndex(6);

	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);
end

function Lua_TrialEachItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end
	
	self.titleTxt.text = data.name;
    self.rightTopIcon:setEnable(DataCenter.TrialData.rec_Index == data.id);

	self.rewardList:setArrayData(data.reward);

	self.goldBg:setEnable(false);
	self.refreshBtn:setGray(false);
	self.refreshBtn.txt:setLocation(0, 3, 0);

	self.conditionLbl:setEnable(data.state == 0);
    self.mask:setEnable(data.state == 0);

	local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.trial_select_type);
    if data.state == 0 then
		self.refreshBtn:setGray(true);
		self.refreshBtn:setLangValue(200603); -- 未开启

		local lightTowerVo = DataCenter.climbTowerData:getTowerVoById(Lua_ClimbTowerUtil.LIGHT_ID);
		if lightTowerVo ~= nil and lightTowerVo.cur_storey < data.stage_id then
			self.conditionLbl.text = LanUtil.formateStr(data.stage_name, tostring(data.stage_id));
		else
			self.conditionLbl.text = LanUtil.formateStr(data.level_name, tostring(data.level));
		end
	elseif data.state == 1 then
		self.refreshBtn:setLangValue(200604); -- 挑 战
	else
		if select_data.free_times > 0 then
			self.refreshBtn:setLangValue(200605); -- 扫荡
		else
			if select_data.sweep_cost ~= nil then
				self.goldBg:setEnable(true);
				self.refreshBtn.label = select_data.sweep_cost..LanUtil.getValue(200605);
				local totalW = self.refreshBtn.txt.width + self.goldBg.width;
				self.refreshBtn.txt:setLocation(totalW / 2 - self.refreshBtn.txt.width / 2, 3, 0);
			else
				self.refreshBtn:setLangValue(200605);
			end
		end
	end
end

function Lua_TrialEachItem:onPressClick()
	self.rewardList:onBoundClick();
end

function Lua_TrialEachItem:onRefreshBtnClick(go)
	if self.data.state == 0 then
		local str1 = "";
		local lightTowerVo = DataCenter.climbTowerData:getTowerVoById(Lua_ClimbTowerUtil.LIGHT_ID);
		if lightTowerVo ~= nil and self.data.stage_id > 0 then
			str1 = LanUtil.formateStr(200613, tostring(self.data.stage_id));
		end
		
		if str1 ~= "" then
			str1 = str1 .. LanUtil.getValue(200614);
		end

		local str2 = LanUtil.formateStr(200615, tostring(self.data.level));
		OperateAlert.show(LanUtil.formateStr(200616, str1 .. str2));
	elseif self.data.state == 1 then
		local minIndex = DataCenter.TrialData:getTypeMinIndex(DataCenter.TrialData.trial_select_type);
		if self.data.id > minIndex or minIndex == nil then
			OperateAlert.showLangValue(200606) -- 请先挑战上一难度
		else
			local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.trial_select_type);
			local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(select_data.fight_id);
			DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, select_data.fight_id, sceneId, 0);
		end
	elseif self.data.state == 2 then
		local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.trial_select_type);
		if select_data.free_times > 0 then
			Lua_ProxyManager.getProxy("Lua_TrialProxy"):sClear(self.data.id);
		else
			if select_data.sweep_cost == nil then
				OperateAlert.showLangValue(200617);
				return;
			end

			if DataCenter.roleData.vip > 0 then
				if select_data.challenge_times > 0 then
					if DataCenter.moneyData:isMoneyEnough(Lua_ResourcesDefine.DIAMOND, tonumber(select_data.sweep_cost), true, false, true) then
						OperateAlert.showLangValue(200618);
						Lua_ProxyManager.getProxy("Lua_TrialProxy"):sClear(self.data.id);
					end
				else
					if DataCenter.roleData.vip < select_data.buy_max_vip then
						OperateAlert.showLangValue(200607) -- 提升vip等级可增加购买次数
					else
						OperateAlert.showLangValue(200608) -- 次数不足
					end
				end
			else
				OperateAlert.showLangValue(200609)
			end
		end
	end
end

function Lua_TrialEachItem:onSceneShow(param)
	local data = { template_id = param, stage_id = tonumber(self.data.id), monster_player_id = self.data.monster_id };
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, data);
end

function Lua_TrialEachItem:dispose()
	if self.rewardList ~= nil then
        self.rewardList:dispose();
        self.rewardList = nil;
    end
    self.data = nil;
    DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);

	self:superCall("dispose");
end