-- 试炼副本
checkRequire("Lua_TrialPanel")
Lua_TrialWindow = class("Lua_TrialWindow", Lua_Window);
function Lua_TrialWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAIN_MENU_LAYER;
	self.windowName = "Lua_TrialWindow";
	self.winBgPath = "/images/common/ui_common_bg_001.jpg";
	self.showWinBg = true;
	self.isFullSizeWin = true;
	self.showBackBtn = true;
end

function Lua_TrialWindow:buildShowItem()
	self:superCall("buildShowItem");
	
	self.btnList = Lua_DragList.new(self.content, 720, 126, Lua_AxisDefine.Horizontal);
	self.btnList:setListCell(Lua_TrialBtnItem, 220, 126, 1);
	self.btnList:setLocation(0, 175, 0);
	self.btnList:setCellSpacing(5, 0);
	self.btnList:setSiblingIndex(1);
	self.btnList:setRectAnchor(7);

	self:addLuaEvent("TRIAL_PANEL_CECLICK", self, self.selectPanel);
end

function Lua_TrialWindow:showWin(param)
	self:superCall("showWin", param);

	self.openIndex = 1;
	if param ~= nil then
		if type(param) == "table" and param.type ~= nil then
			self.openIndex = param.type;
		elseif type(param) == "string" or type(param) == "number" then
			self.openIndex = tonumber(param);
		end
	end
	self:updateShowInfo(self.openIndex);
end

function Lua_TrialWindow:updateShowInfo(openIndex)
	local showArr = DataCenter.TrialData:getTrialTypeArr();
	if showArr == nil or showArr:getSize() <= 0 then
		return;
	end

	self.btnList.canDrag = showArr:getSize() > 3;
	self.btnList:setArrayData(showArr);
	self.btnList:moveToIndex(openIndex, true);
	self.btnList.showDragDataList[openIndex].cell:onPressClick();
	self.btnList:setSelected(openIndex);
end

function Lua_TrialWindow:selectPanel(val)
	if self.selectType == val then
		return;
	end
	self.selectType = val;

	if self.curPanel == nil then
		self.curPanel = Lua_TrialPanel.new(self.content, self.selectType);
		self.curPanel:setSiblingIndex(1);
		self.curPanel:setRectSize(self.width, self.height);
	end
	self.curPanel:setType(self.selectType);
	Lua_ProxyManager.getProxy("Lua_TrialProxy"):sTrialTypeInfo(self.selectType);
end

function Lua_TrialWindow:onScreenResize()
	self:superCall("onScreenResize");

	if self.curPanel ~= nil then
		self.curPanel:setRectSize(self.width, self.height);
	end
end

function Lua_TrialWindow:dispose()
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.curPanel ~= nil then
		self.curPanel:dispose();
		self.curPanel = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_TrialBtnItem = class("Lua_TrialBtnItem", Lua_ListCell);
function Lua_TrialBtnItem:ctor(p)
	self:superCall("ctor", p, "TrialBtn_skin");
end

function Lua_TrialBtnItem:buildShowItem()
	self:superCall("buildShowItem");

	self.tipsIocn = UICreate.createUIAtlasImage(self.content, "trial_altas", "ui_shilian_widget_005", 0, 4, 0, 0);
	self.tipsIocn:setEnable(false);
end

function Lua_TrialBtnItem:setData(data)
	if data == nil then
		return;
	end
	self.data = data;
	self.bg:setAltas(data.trialIcon[1], data.trialIcon[2]);

	if data.game_level_id ~= nil and DataCenter.mainLineData:getCheckpointIsCompleted(data.game_level_id) == false then
		local config = Lua_MainLineCheckpointConfigData.getConfig(data.game_level_id);
		self.openCondTxt.text = LanUtil.formateStr(200612, config.name);
		self.openCondTxt:setEnable(true);
		self.openCondBg:setEnable(true);
		self.mask:setEnable(true);
	else
		self.openCondTxt.text = LanUtil.formateStr(200610, data.open_level);
		self.openCondTxt:setEnable(DataCenter.roleData.level < data.open_level);
		self.openCondBg:setEnable(DataCenter.roleData.level < data.open_level);
		self.mask:setEnable(DataCenter.roleData.level < self.data.open_level);
	end

	if self.redPointIcon == nil then
		self.redPointIcon = Lua_RedPointIcon.new(self.content, data.redPointId);
		self.redPointIcon:setLocation(100, 50, 0);
	else
		self.redPointIcon:changeRedPoint(data.redPointId);
	end
end

function Lua_TrialBtnItem:onPressClick()
	if DataCenter.funcOpenData:isOpened(self.data.open_id, true) then
		DataCenter.TrialData.selectType = self.data.id;
		Lua_MsgUtil.callFunc("TRIAL_PANEL_CECLICK", self.data.id);
		return true;
	end
	return false;
end

function Lua_TrialBtnItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);

	self.tipsIocn:setEnable(bSelect);
end

function Lua_TrialBtnItem:dispose()
	if self.tipsIocn ~= nil then
		self.tipsIocn:dispose();
		self.tipsIocn = nil;
	end
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self.data = nil;

	self:superCall("dispose");
end